#!/bin/sh
# common variables
typeset -ri _TRUE=0
typeset -ri _FALSE=1
typeset -ri _VERBOSE=$_FALSE
typeset -r _MESSAGES="./dellIPMI_msgs.sh"
typeset -r _DUPUTIL="./duputil.sh"
typeset -r _MINIMUM_HAPI_RPM_VERSION=5.0.0
bVerbose() {
    [ $_VERBOSE -eq $_TRUE ]
}

# set errorXml tags
typeset tag=Execution
[ "-xml" = ${1:-none} ] && tag=Inventory
[ "-i" = ${1:-none} ] && tag=Inventory

# produce error Xml with message argument
errorXml() {
    local msg=$1
    cat << EOXML
<?xml version="1.0" encoding="UTF-8" ?>
<SVM$tag lang="en">
    <SPStatus result="false">
        <Message id="1">$msg</Message>
    </SPStatus>
</SVM$tag>
EOXML
    exit $_FALSE
}

verify_nonUserMode_Hapi() {
    ## Need to verify IPMI if _DUPUTIL finds a hapi RPM version older than srvadmin-hapi-5.0.0
    source $_DUPUTIL $_MINIMUM_HAPI_RPM_VERSION || {
	bVerbose && echo "Continue with non-User-mode Hapi IPMI verification"
        source $_MESSAGES
        bVerbose && echo Verifying IPMI
        ## Verify IPMI - block if this device is loaded 
        lsmod | grep -qE '^ipmi_(devintf|si|msghandler)[[:space:]]' && 
            errorXml "$_MSG_IPMI_DRIVER_ERROR"
        grep -q '[[:space:]]ipmidev$' /proc/devices && 
            errorXml "$_MSG_IPMI_DRIVER_ERROR"
	bVerbose && echo "non User-mode HAPI IPMI verification successful"
	return $_TRUE
    }
    bVerbose && echo "Continue with User-mode Hapi pre-requisite checking"
    return $_FALSE
}

## Verify IMB - block if this device is loaded 
[ -c '/dev/imb' ] && {
    source $_MESSAGES
    errorXml "$_MSG_IMB_DRIVER_ERROR"
}
verify_nonUserMode_Hapi && return $_TRUE

## User-mode HAPI verification 
## Verify IPMI - block with error if OpenIPMI install/upgrade 
cd prereqcheck > /dev/null 2>&1
source openipmifuncs.sh
#bVerbose && set -vx
CheckOpenIPMIDriverStatus "./sysreport" "./syslisttypes.txt" "./syslist.txt"
typeset -ri _IPMI_STATUS=$?
cd - > /dev/null 2>&1


## Set IPMI packaged version
typeset _PACKAGED_VERSION
[ "${LOC_OS_TYPE}" = "${GBL_OS_TYPE_RHEL3}" ] && \
    _PACKAGED_VERSION=$GBL_PACKAGED_DRIVER_VERSION_RHEL3
[ "${LOC_OS_TYPE}" = "${GBL_OS_TYPE_RHEL4}" ] && \
    _PACKAGED_VERSION=$GBL_PACKAGED_DRIVER_VERSION_RHEL4
[ "${LOC_OS_TYPE}" = "${GBL_OS_TYPE_SLES9}" ] && \
    _PACKAGED_VERSION=$GBL_PACKAGED_DRIVER_VERSION_SLES9

## Issue messages
[ $GBL_ACTION_ERROR -eq $_IPMI_STATUS ] && {
    source $_MESSAGES
    errorXml "$_MSG_GENERIC_HAPI_ERROR"
}
[ $GBL_ACTION_DO_NOTHING -eq $_IPMI_STATUS ] && {
    bVerbose && echo "IPMI version $_PACKAGED_VERSION is up to date, continue with DUP execution." >&2
}
[ $GBL_ACTION_INSTALL_DRIVER_BY_INSTALLING_RPM_ON_IPMI -eq $_IPMI_STATUS -o \
$GBL_ACTION_INSTALL_DRIVER_BY_UPGRADING_RPM_ON_IPMI -eq $_IPMI_STATUS ] && {
    _MSG_DOWNLOAD_PARM=install
    source $_MESSAGES
    errorXml "$_MSG_IPMI_INSTALL  $_MSG_DOWNLOAD_IPMI"
}
[ $GBL_ACTION_UPGRADE_DRIVER_BY_INSTALLING_RPM_ON_IPMI -eq $_IPMI_STATUS -o \
$GBL_ACTION_UPGRADE_DRIVER_BY_UPGRADING_RPM_ON_IPMI -eq $_IPMI_STATUS ] && {
    _MSG_DOWNLOAD_PARM=upgrade
    source $_MESSAGES
    errorXml "$_MSG_IPMI_UPGRADE  $_MSG_DOWNLOAD_IPMI"
}
[ $GBL_ACTION_INSTALL_DRIVER_BY_INSTALLING_RPM_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_UPGRADE_DRIVER_BY_INSTALLING_RPM_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_INSTALL_DRIVER_BY_UPGRADING_RPM_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_UPGRADE_DRIVER_BY_UPGRADING_RPM_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_INSTALL_DRIVER_BY_INSTALLING_SOURCE_AND_USING_DKMS_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_UPGRADE_DRIVER_BY_INSTALLING_SOURCE_AND_USING_DKMS_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_INSTALL_DRIVER_BY_USING_DKMS_ON_TVM -eq $_IPMI_STATUS -o \
$GBL_ACTION_UPGRADE_DRIVER_BY_USING_DKMS_ON_TVM -eq $_IPMI_STATUS ] && {
    export OMIIGNOREOPENIPMI=1
    bVerbose && echo "TVM is currently active on this system, continue with DUP execution." >&2
}
[ $GBL_ACTION_INSTALL_DRIVER_BY_INSTALLING_SOURCE_AND_USING_DKMS_ON_IPMI -eq $_IPMI_STATUS ] && {
    source $_MESSAGES
    errorXml "$_MSG_IPMI_INSTALL $_MSG_DKMS_AND_KERNEL_SOURCE"
}
[ $GBL_ACTION_INSTALL_DRIVER_BY_USING_DKMS_ON_IPMI -eq $_IPMI_STATUS ] && {
    source $_MESSAGES
    errorXml "$_MSG_IPMI_INSTALL $_MSG_DKMS"
}
[ $GBL_ACTION_UPGRADE_DRIVER_BY_INSTALLING_SOURCE_AND_USING_DKMS_ON_IPMI -eq $_IPMI_STATUS ] && {
    source $_MESSAGES
    errorXml "$_MSG_IPMI_UPGRADE $_MSG_DKMS_AND_KERNEL_SOURCE"
}
[ $GBL_ACTION_UPGRADE_DRIVER_BY_USING_DKMS_ON_IPMI -eq $_IPMI_STATUS ] && {
    source $_MESSAGES
    errorXml "$_MSG_IPMI_UPGRADE $_MSG_DKMS"
}

#bVerbose && set +vx

return $_TRUE

